@@ -1,26 +1,33 @@
-#!/usr/bin/perl -w
-use strict;
-#does nothing if run! 
-#
+#!/usr/bin/perl 
+
+BEGIN { require $_.".pm" && $_->import for qw(strict warnings) }
+
+=pod
+
+=head1 NAME
+
+=over
+
+•mem - use modules from "mem"ory & allow consistent syntax for inits
+
+=head1 VERSION
+
+Version "0.4.6"
+
+=cut
 
 package mem;  
-  our $VERSION='0.4.5';
+  our $VERSION='0.4.6';
 	
-	our %os2sep = ( Wi => "\x{5c}", MS => "\x{5c}" );
-
-	sub sep_detect() {
-#		my $OS = substr(($ENV{OS} || $^O),0,2); 
-#		defined $os2sep{$OS} ? $os2sep{$OS} : 
-		'/';
-	}
-
   # RCS $Revision: 1.7 $ $Date: 2013-12-16 13:21:47-08 $
+	# 0.4.6	  - conditionalize warning & strict based on presence;  Documentation
+	#           changes.
 	# 0.4.5		- Add alt version format for ExtMM 
 	# 0.4.4		- Add dep on recent ExtMM @ in BUILD_REQ
 	#           Documentation enhancements and clarifications.
 	# 0.4.3		- change format of VERSION to a string (vec unsupported
 	# 					in earlier perl versions)
-	# 0.4.2		- doc change & excisement of  a symlink (maybe winprob)
+	# 0.4.2		- doc change & excisement of a symlink (maybe winprob)
 	# 0.4.1		- revert attempt to use win32 BS -- seems to cause
 	# 					more problems than it fixed.
 	# 0.4.0		- Documentation upgrade; 
@@ -30,6 +37,8 @@ package mem;
 	#	0.3.1		- Fix Manifest => MANIFEST
 	#	0.3.0		- Initial external 'non'-release
 
+	sub sep_detect() { '/' }
+
 	our $sep;
 
   sub import { 
@@ -50,25 +59,6 @@ package mem;
 ##########################################################################
 #                 use mem; {{{1
 
-=pod
-
-=head1 NAME
-
-=over
-
-=item 
-
-mem  -  use "in-mem" pkgs & force definitions into mem early
-
-=back
-
-=head1 VERSION
-
-=over 
-
-Version "0.4.5"
-
-=back
 
 =head1 SYNOPSIS
 
@@ -76,39 +66,54 @@ Version "0.4.5"
   use mem;
   use mem(@COMPILE_TIME_DEFINES=qw(a b c));
 
-B<C<mem>> is a trivial pragma to either allow defining the module it is included from as being defined so that later classes or packages in the same file can C<use> the package to pull in a reference to it, or to be able to call its import routine from a different package in the same file.
+B<C<mem>> is a I<syntactic-sugar> C<pragma> that allows C<use>-ing a C<package> as it is previously defined, B<in the same file>. This allows easy declaration of specialized, typed data structures (like I<C> C<struct> definitions) that increase code legibility and concept clarity.  In a similar usage, the L<constants> pragma allows defining low-overhead, runtime constants. 
 
-With parameter assignments or other actions, it forces those assignments to be
-done, immediately, at compile time instead of later at run time.  It can be use, for example, with Exporter, to export typed-sub's among other usages.
+Allowing C<use> of packages in the same file allows calling code to access classes in a clean, object oriented manner, allowing for identical code to
+exist either in the same file, or in a separate file without making code
+changes or requiring use of non-portable, language specific features to
+accomplish the same thing.
 
+In the 2nd form, it allows compile-time assignments to variables in a way
+that smoothly integrates needed assignments into header blocks without
+disrupting the layout and flow of the code with the increased 
+visual clutter added by BEGIN blocks that have their own syntax.
+
+In many cases, these compile time assignments are essential to take full
+advantage of perl's strengths.  For example, without compile time assignment
+of '@EXPORT', you can't use perl's function prototypes.  Due the overhead and difficulty in getting them right, new perl programmers are dissuaded from
+using such featues.
+
+When used to force assignments into the early parsing stages of perl, Using dynamically allocated, pre-initialized and type-checked data structures become
+possible.
 
 =head1 EXAMPLE
 
-Following, is a sample program, showing two uses of C<mem>.
+Following, is a sample program, showing two uses of  C<mem> .  This first example allows declaring a run-time keyword 'ARRAY', that can check to see
+if it's argument is an ARRAY reference, B<and> provide a runtime
+literal,  C<ARRAY> , that can be used without quotes.
 
   use strict; use warnings;
 
   { package Ar_Type;
       #
       use mem;                                    #1st usage 
-      our (@EXPORT, @ISA);
+      our (@EXPORT);
       sub ARRAY (;*) {
           my $p = $_[0]; my $t="ARRAY";
           return @_ ? (ref $p && (1+index($p, $t))) : $t;
       }
       #
       use mem(                                    #2nd usage 
-          @EXPORT=qw(ARRAY), @ISA=qw(Exporter)
+          @EXPORT=qw(ARRAY),
       #
       )                                           #(also) 2nd usage 
       ;
-      use Exporter;
+      use Xporter;
   }
 
   package main;
   use Ar_Type;
   use P;
-	use Types::Core
 
   my @a=(1,2,3);
   my ($ed, $light);
@@ -116,9 +121,9 @@ Following, is a sample program, showing two uses of C<mem>.
   bless $ed, "bee";
 
   P "\@a = ref of array" if ARRAY \@a;
-  P "ref of ed is %s", ref $ed;
+  P "ref of \$ed is \"%s\".", ref $ed;
   P "ed still points to underlying type, 'array'" if ARRAY $ed;
-  P "Is ref \$light, ARRAY?: %s", (ref $light eq ARRAY) ? 'yes':'no';
+  P "Is ref \$light, an ARRAY?: %s", (ref $light eq ARRAY) ? 'yes':'no';
   P "Does \"ref \$ed\" eq ARRAY?: %s", (ref $ed eq ARRAY) ? 'yes':'no';
   P "%s", "#  (Because \"ref \$ed\" is really a bless \"ed\" bee)"
 
@@ -126,14 +131,15 @@ Following, is a sample program, showing two uses of C<mem>.
 
 =item 
 
-First, the correct output:
+Now, to show what happens using  C<mem>, and the errors that occur if you
+do not.  First, the correct output:
 
   @a = ref of array
-  ref of ed is bee
+  ref of $ed is "bee".
   ed still points to underlying type, 'array'
-  Is ref $light, ARRAY?: yes
+  Is ref $light, an ARRAY?: yes
   Does ref $ed eq ARRAY?: no
-  #  (Because ref "ed" is really a bless "ed" bee)
+  #  (Because ref "ed" is really a bless"ed" bee)
 
 
 =item 
@@ -141,7 +147,7 @@ First, the correct output:
 Second, B<I<without>> the first "C< use mem >", presuming the line was commented out:
 
   Can't locate Ar_Type.pm in @INC (@INC contains: 
-    /usr/lib/perl5/5.16.2 ...   /usr/lib/perl5/site_perl .) 
+    /usr/lib/perl5/5.18.2 ...   /usr/lib/perl5/site_perl .) 
     at /tmp/ex line 18.
   BEGIN failed--compilation aborted at /tmp/ex line 18.  
 
@@ -175,7 +181,7 @@ Third, instead of dropping the 1st "C< use mem >", you drop (or comment out) the
   Execution of /tmp/ex aborted due to compilation errors. 
 
 
-This happens because when C<use Exporter> is called, the 
+This happens because when C<use Xporter> is called, the 
 contents of C<@EXPORT> is not known.  Even with the assignment
 to C<@EXPORT>, the "C<@EXPORT=qw(ARRAY)>" being right above
 the C<use Exporter> statement.  Similarly to the first error, above,
@@ -202,14 +208,12 @@ In B<both> cases, C<mem> allows your already-in-C<mem>ory code to
 be used.  Thsi allows simplified programming and usage without knowledge
 of or references to Perl's internal-flags or internal run phases.
 
+
 =head1 SEE ALSO
 
-
-See L<Exporter> for information on exporting names.  See the newer, 
-L<Xporter> for doing similar without the need for setting C<@ISA>
-and persistent defaults in C<@EXPORT>. See L<P> for more details about 
-the generic print verb and see L<Types::Core> for a more complete
-treatment of the CORE Types.
+See L<Xporter> for more help with exporting features from your modules, or
+the older L<Exporter> for the cadillac of exporting that will do everything you want (and a bit more). See L<P> for more details about 
+the generic print operator that is actually B<user friendly>, and see L<Types::Core> for a more complete treatment of the CORE Types (with helpers for other perl data types besides  C<ARRAY>'s.
 
 
 
